// Copyright Jean Francois Perusse 2006
// All rights reserved
//
// This file is part of the Google Desktop SDK and may be freely copied and used.
// To download the latest version of the SDK please visit
// http://desktop.google.com/developer.html

view.caption = strTitle;
contentArea.contentFlags = gddContentFlagNone;
googleTalk.onReceiveTalkData = OnReceiveTalkData;

// check once every 'x' microseconds
view.setInterval(StatusTimer, 60000);
view.setInterval(AckTimer, 300000);
ResetUsers();
StatusTimer();

function ResetUsers() {
  options.removeAll();
}

function IsRunning() {
  // Check if we are running "WoW.exe"
  var objWMIService;
  var colProcess;

  objWMIService = GetObject("winmgmts:{impersonationLevel=impersonate}!//./root/cimv2");

  colProcess = objWMIService.ExecQuery("SELECT * FROM Win32_Process");

  var e = new Enumerator(colProcess);
  for (; !e.atEnd(); e.moveNext()) {
    if (e.item().Name == "WoW.exe") {
      return true;
    }
  }

  return false;
}

function MySendTalkData(friend, data) {
  var messageIndex = 0;
  if (options.exists(strMsgIndex)) {
    messageIndex = options.item(strMsgIndex);
    options.remove(strMsgIndex);
  }
  messageIndex++;
  if (messageIndex >= 10000000) messageIndex = 0;
  options.add(strMsgIndex, messageIndex);

  data = data + messageIndex;
  
  //view.alert("Sending (" + friend.name + ", " + data + ")");
  googleTalk.SendTalkDataEx(friend.user_id, data, 1);
}

function OnReceiveTalkData(friend, data) {
  //view.alert("Receiving (" + friend.name + ", " + data + ")" + friend.user_id);

  // Make sure the friend is our list!
  var online = false;
  var friends = googleTalk.friends.toArray();
  for(var i = 0; i < friends.length; i++) {
    var fr = friends[i];
    if (fr.user_id == friend.user_id) {
      online = true;
    }
  }
  if (!online) {
    if (options.exists(friend.user_id)) {
      options.remove(friend.user_id);
    }
    return;
  }

  var bRunning = IsRunning();

  var ackString = strAck + friend.user_id;

  if (data.indexOf(strRunning) != -1) {
    data = strRunning;
  } else if (data.indexOf(strNotRunning) != -1) {
    data = strNotRunning;
  }

  if (data == strRunning || data == strNotRunning) {
    if (options.exists(friend.user_id)) {
      if (options.item(friend.user_id) == strNotRunning && data == strRunning) {
        var newItem = new ContentItem();
        newItem.heading = friend.name;
        newItem.snippet = "Started playing World of Warcraft.";
        pluginHelper.AddContentItem(newItem, gddItemDisplayInSidebar + gddItemDisplayAsNotification);
        pluginHelper.RemoveContentItem(newItem);
      }
      options.remove(friend.user_id);
    }
    if (!options.exists(ackString)) {
      options.add(ackString, ackString);
    }
    options.add(friend.user_id, data);
  }
  UpdateView();
}

function SendStatus(friend) {
  var bRunning = IsRunning();
  if (bRunning) {
    MySendTalkData(friend, strRunning);
  } else {
    MySendTalkData(friend, strNotRunning);
  }
}

function UpdateView() {
  // Remove all items from the contentArea
  contentArea.removeAllContentItems();

  //Display all our friends status
  var notAvailable = new Array();
  var notPlaying   = new Array();
  var playing      = new Array();

  var friends = googleTalk.friends.toArray();
  for(var i = 0; i < friends.length; i++) {
    var fr = friends[i];
    var item = new ContentItem();
    item.heading = fr.name;
    item.flags = gddContentItemFlagNoRemove;
    item.layout = gddContentItemLayoutNews;
    if (options.exists(fr.user_id)) {
      if (options.item(fr.user_id) == strRunning) {
        item.source = "Playing WoW";
        playing.push(item);
      } else if (options.item(fr.user_id) == strNotRunning) {
        item.source = "Not playing WoW";
        notPlaying.push(item);
      }
    } else {
      item.source = "Status not available";
      notAvailable.push(item);
    }
  }
  // Sort all the items, "playing" will be the first to show.
  for(var i = 0; i < notAvailable.length; i++) {
    // add the item to the display
    contentArea.addContentItem(notAvailable[i], gddItemDisplayInSidebar);
  }
  for(var i = 0; i < notPlaying.length; i++) {
    // add the item to the display
    contentArea.addContentItem(notPlaying[i], gddItemDisplayInSidebar);
  }
  for(var i = 0; i < playing.length; i++) {
    // add the item to the display
    contentArea.addContentItem(playing[i], gddItemDisplayInSidebar);
  }
}

function StatusTimer() {
  // Verify if we are running WoW and add local status in title.
  var bRunning = IsRunning();
  if (bRunning) {
    view.caption = "WoW is running";
  } else {
    view.caption = "WoW is not running";
  }

  // Send our running information to our GoogleTalk friends.
  var friends = googleTalk.friends.toArray();
  for(var i = 0; i < friends.length; i++) {
    var fr = friends[i];
    SendStatus(fr);
  }
  // Update the view
  UpdateView();
}

function AckTimer()
{
  var friends = googleTalk.friends.toArray();
  for(var i = 0; i < friends.length; i++) {
    var fr = friends[i];
    var ackString = strAck + fr.user_id;
    if (options.exists(ackString)) {
      options.remove(ackString);
    } else {
      options.remove(fr.user_id);
    }
  }
}

